aboutsummaryrefslogtreecommitdiffstats
path: root/codecs/codec_alaw.c
diff options
context:
space:
mode:
authormarkster <markster@f38db490-d61c-443f-a65b-d21fe96a405b>2002-11-29 02:14:13 +0000
committermarkster <markster@f38db490-d61c-443f-a65b-d21fe96a405b>2002-11-29 02:14:13 +0000
commit69399315991bf7f9679e2d9b22f42415653cfc04 (patch)
treee3349bbc37c69394a11f4358e9af9f7a5d2a2329 /codecs/codec_alaw.c
parent2d459a804c0512bbceafe63a934770c2aa3f5edd (diff)
Version 0.3.0 from FTP
git-svn-id: http://svn.digium.com/svn/asterisk/trunk@556 f38db490-d61c-443f-a65b-d21fe96a405b
Diffstat (limited to 'codecs/codec_alaw.c')
-rwxr-xr-xcodecs/codec_alaw.c10
1 files changed, 5 insertions, 5 deletions
diff --git a/codecs/codec_alaw.c b/codecs/codec_alaw.c
index 833092365..54a464cfc 100755
--- a/codecs/codec_alaw.c
+++ b/codecs/codec_alaw.c
@@ -151,7 +151,7 @@ alawtolin_framein (struct ast_translator_pvt *pvt, struct ast_frame *f)
*
* Results:
* Converted signals are placed in tmp->f.data, tmp->f.datalen
* and tmp->f.timelen are calculated.
*
* Side effects:
* None.
@@ -168,7 +168,7 @@ alawtolin_frameout (struct ast_translator_pvt *pvt)
tmp->f.frametype = AST_FRAME_VOICE;
tmp->f.subclass = AST_FORMAT_SLINEAR;
tmp->f.datalen = tmp->tail *2;
- tmp->f.timelen = tmp->tail / 8;
+ tmp->f.samples = tmp->tail;
tmp->f.mallocd = 0;
tmp->f.offset = AST_FRIENDLY_OFFSET;
tmp->f.src = __PRETTY_FUNCTION__;
@@ -226,7 +226,7 @@ lintoalaw_frameout (struct ast_translator_pvt *pvt)
if (tmp->tail) {
tmp->f.frametype = AST_FRAME_VOICE;
tmp->f.subclass = AST_FORMAT_ALAW;
- tmp->f.timelen = tmp->tail / 8;
+ tmp->f.samples = tmp->tail;
tmp->f.mallocd = 0;
tmp->f.offset = AST_FRIENDLY_OFFSET;
tmp->f.src = __PRETTY_FUNCTION__;
@@ -249,7 +249,7 @@ alawtolin_sample ()
f.frametype = AST_FRAME_VOICE;
f.subclass = AST_FORMAT_ALAW;
f.datalen = sizeof (ulaw_slin_ex);
- f.timelen = sizeof(ulaw_slin_ex) / 8;
+ f.samples = sizeof(ulaw_slin_ex);
f.mallocd = 0;
f.offset = 0;
f.src = __PRETTY_FUNCTION__;
@@ -269,7 +269,7 @@ lintoalaw_sample ()
f.subclass = AST_FORMAT_SLINEAR;
f.datalen = sizeof (slin_ulaw_ex);
/* Assume 8000 Hz */
- f.timelen = sizeof (slin_ulaw_ex) / 16;
+ f.samples = sizeof (slin_ulaw_ex) / 2;
f.mallocd = 0;
f.offset = 0;
f.src = __PRETTY_FUNCTION__;
@@ -151,7 +151,7 @@ alawtolin_framein (struct ast_translator_pvt *pvt, struct ast_frame *f)
* Results:
* Converted signals are placed in tmp->f.data, tmp->f.datalen
- * and tmp->f.timelen are calculated.
+ * and tmp->f.samples are calculated.
*
* Side effects: